@@ -230,12 +230,6 @@ class MLP:
 
 
     def _get_stanza_tokens(self, lang: str, raw_text: str):
-        # This is a HACK to compensate Stanza errors in tokenizing Russian phone numbers
-        # Replaces "-" between digits to "_" so it won't be split into separate tokens (1/2)
-        pat = re.compile(r"(?<=\d)-(?=\d)")
-        if lang == "ru":
-            raw_text = pat.sub("_", raw_text)
-
         pipeline = self.stanza_pipelines[lang](raw_text)
 
         sentences = []
@@ -244,10 +238,6 @@ class MLP:
         for sentence in pipeline.sentences:
             words = []
             for word in sentence.words:
-                # Russian HACK (2/2)
-                # replaces back "#" to "-" between digits.
-                if lang == "ru":
-                    word.text = pip_pat.sub("-", word.text)
                 words.append(word)
             sentences.append(words)
             for entity in sentence.entities:
@@ -270,12 +260,25 @@ class MLP:
             stanza_pipelines[lang] = stanza.Pipeline(
                 lang=lang,
                 dir=str(stanza_resource_path),
+                processors=self._get_stanza_processors(lang),
                 use_gpu=self.use_gpu,
                 logging_level=logging_level
             )
         return stanza_pipelines
 
 
+    @staticmethod
+    def _get_stanza_processors(lang):
+        """
+        Returns processor options based on language and NER support in Stanza.
+        """
+        print(lang)
+        if lang in STANZA_NER_SUPPORT:
+            return "tokenize,pos,lemma,ner"
+        else:
+            return "tokenize,pos,lemma"
+
+
     def process(self, raw_text: str, analyzers: list = ["all"], lang=None):
         """
         Processes raw text.
@@ -290,7 +293,7 @@ class MLP:
             for analyzer in loaded_analyzers:
                 # For every analyzer, activate the function that processes it from the
                 # document class.
-                getattr(document, analyzer)()
+                self.__apply_analyzer(document, analyzer)
             return document.to_json()
         else:
             return None
@@ -328,6 +331,13 @@ class MLP:
             return []
 
 
+    def __apply_analyzer(self, doc, analyzer):
+        try:
+            getattr(doc, analyzer)()
+        except Exception as e:
+            self.logger.exception(e)
+
+
     def process_docs(self, docs: List[dict], doc_paths: List[str], analyzers=["all"]):
         """
         :param docs: Contains tuples with two dicts inside them, the first being the document to be analyzed and the second is the meta information that corresponds to the document for transport purposes later on.
@@ -349,7 +359,7 @@ class MLP:
                         for analyzer in analyzers:
                             # For every analyzer, activate the function that processes it from the
                             # document class.
-                            getattr(doc, analyzer)()
+                            self.__apply_analyzer(doc, analyzer)
 
                         result = doc.document_to_json(use_default_doc_path=False)
                         new_facts = result.pop("texta_facts", [])
